Index: wp-includes/post-functions.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/post-functions.php	(revision 692452336634cf29d06f2414b1187a58159430ae)
+++ wp-includes/post-functions.php	(revision )
@@ -499,19 +499,17 @@
  * @see sanitize_post_field()
  *
  * @param string      $field   Post field name.
  * @param int|WP_Post $post    Post ID or post object.
  * @param string      $context Optional. How to filter the field. Accepts 'raw', 'edit', 'db',
  *                             or 'display'. Default 'display'.
+ * @param mixed       $default Optional. Default value.
  * @return string The value of the post field on success, empty string on failure.
  */
-function get_post_field( $field, $post, $context = 'display' ) {
+function get_post_field( $field, $post = null, $context = 'display', $default = '' ) {
 	$post = get_post( $post );
 
-	if ( !$post )
-		return '';
-
-	if ( !isset($post->$field) )
-		return '';
+	if ( !$post || !isset($post->$field) )
+		return $default;
 
 	return sanitize_post_field($field, $post->$field, $post->ID, $context);
 }
@@ -499,19 +499,17 @@
  *
  * @param string      $field   Post field name.
- * @param int|WP_Post $post    Post ID or post object.
+ * @param int|WP_Post $post    Optional. Post ID or post object. Default: null
  * @param string      $context Optional. How to filter the field. Accepts 'raw', 'edit', 'db',
  *                             or 'display'. Default 'display'.
